@@ -26,8 +26,6 @@
 #include <QRect>
 #include <QLabel>
 #include <QTimer>
-#include <QPainter>
-#include <QHelpEvent>
 #include <QScrollBar>
 #include <QGridLayout>
 #include <QApplication>
@@ -247,4 +245,3 @@ QLayout * ToolTipManager::generateToolTipLine( QModelIndex * item, QWidget * too
     return layout;
 }
 
-#include "tooltipmanager.moc"
